summaryrefslogtreecommitdiffstats
path: root/chrome/browser/navigation_controller.h
diff options
context:
space:
mode:
authorsky@google.com <sky@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2008-10-30 16:17:04 +0000
committersky@google.com <sky@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2008-10-30 16:17:04 +0000
commitf1c7411610f2f849f74eb8d911665e607657a028 (patch)
tree36ec27c156cf13364d894cda85b0bd2d480577ec /chrome/browser/navigation_controller.h
parent4a2a0a627b45ecd5541856f7c00f4bc9ada8e766 (diff)
downloadchromium_src-f1c7411610f2f849f74eb8d911665e607657a028.zip
chromium_src-f1c7411610f2f849f74eb8d911665e607657a028.tar.gz
chromium_src-f1c7411610f2f849f74eb8d911665e607657a028.tar.bz2
Makes form resubmission dialog work again. This was a regression
introduced during NavigationController refactoring. BUG=2616 TEST=see bug Review URL: http://codereview.chromium.org/8865 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@4212 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/navigation_controller.h')
-rw-r--r--chrome/browser/navigation_controller.h10
1 files changed, 4 insertions, 6 deletions
diff --git a/chrome/browser/navigation_controller.h b/chrome/browser/navigation_controller.h
index 522c8b1..5b5408f 100644
--- a/chrome/browser/navigation_controller.h
+++ b/chrome/browser/navigation_controller.h
@@ -283,12 +283,10 @@ class NavigationController {
// the offset is out of bounds.
void GoToOffset(int offset);
- // Reloads the current entry. The user will be prompted if the URL has POST
- // data and the active WebContents isn't showing the POST interstitial page.
- void Reload();
-
- // Same as Reload, but doesn't check if current entry has POST data.
- void ReloadDontCheckForRepost();
+ // Reloads the current entry. If |check_for_repost| is true and the current
+ // entry has POST data the user is prompted to see if they really want to
+ // reload the page. In nearly all cases pass in true.
+ void Reload(bool check_for_repost);
// Removing of entries -------------------------------------------------------